From: Brice Goglin <brice@myri•com>
To: Jeff Garzik <jeff@garzik•org>, netdev@vger•kernel.org
Subject: [PATCH 5/7] myri10ge: Full vlan frame in small_bytes
Date: Mon, 11 Dec 2006 11:26:38 +0100 [thread overview]
Message-ID: <457D325E.7090301@myri.com> (raw)
In-Reply-To: <457D31B2.30505@myri.com>
Receive full vlan frames into smalls when running with a jumbo MTU.
Signed-off-by: Brice Goglin <brice@myri•com>
---
drivers/net/myri10ge/myri10ge.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
Index: linux-git/drivers/net/myri10ge/myri10ge.c
===================================================================
--- linux-git.orig/drivers/net/myri10ge/myri10ge.c 2006-12-11 10:52:44.000000000 +0100
+++ linux-git/drivers/net/myri10ge/myri10ge.c 2006-12-11 10:52:51.000000000 +0100
@@ -1650,8 +1650,8 @@
? (128 - MXGEFW_PAD)
: (SMP_CACHE_BYTES - MXGEFW_PAD);
else
- /* enough for an ETH_DATA_LEN frame */
- mgp->small_bytes = ETH_FRAME_LEN;
+ /* enough for a vlan encapsulated ETH_DATA_LEN frame */
+ mgp->small_bytes = VLAN_ETH_FRAME_LEN;
/* Override the small buffer size? */
if (myri10ge_small_bytes > 0)
next prev parent reply other threads:[~2006-12-11 10:27 UTC|newest]
Thread overview: 9+ messages / expand[flat|nested] mbox.gz Atom feed top
2006-12-11 10:23 [PATCH 0/7] myri10ge updates Brice Goglin
2006-12-11 10:24 ` [PATCH 1/7] myri10ge: indentation cleanups Brice Goglin
2006-12-11 14:54 ` Jeff Garzik
2006-12-11 10:25 ` [PATCH 2/7] myri10ge: add page-based skb routines Brice Goglin
2006-12-11 10:25 ` [PATCH 3/7] myri10ge: switch to page-based skb Brice Goglin
2006-12-11 10:26 ` [PATCH 4/7] myri10ge: drop contiguous skb routines Brice Goglin
2006-12-11 10:26 ` Brice Goglin [this message]
2006-12-11 10:27 ` [PATCH 6/7] myri10ge: fix big_bytes in case of vlan frames Brice Goglin
2006-12-11 10:27 ` [PATCH 7/7] myri10ge: update driver version to 1.1.0 Brice Goglin
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=457D325E.7090301@myri.com \
--to=brice@myri$(echo .)com \
--cc=jeff@garzik$(echo .)org \
--cc=netdev@vger$(echo .)kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox